==> random_profile-0.2.4.tar.gz: random_profile-0.2.4/README.md <==

<h1 align="center">
  <a href="https://pypi.org/project/random-profile/">
  Random Profile Generator
  </a>
  V0.2.3
</h1>

<h4 align="center">Python Module To Generate Random Profile Data</h4>

<p align="center">
<img src="https://img.shields.io/pypi/v/random-profile.svg">
<img src="https://img.shields.io/pypi/pyversions/random-profile.svg">
<img src="https://img.shields.io/pypi/l/random-profile.svg">

</p>
<p align="center">
<img src="https://img.shields.io/pypi/dd/random-profile.svg">
<img src="https://img.shields.io/pypi/dw/random-profile.svg">
<img src="https://img.shields.io/pypi/dm/random-profile.svg">
</p>
<p align="center"> 

<img alt="GitHub pull-requests" src="https://img.shields.io/github/issues-pr/Py-Contributors/RandomProfileGenerator">

<img alt="GitHub forks" src="https://img.shields.io/github/forks/Py-Contributors/RandomProfileGenerator"> 

<img alt="contributors" src="https://img.shields.io/github/contributors/Py-Contributors/RandomProfileGenerator"> 

<img alt="GitHub stars" src="https://img.shields.io/github/stars/Py-Contributors/RandomProfileGenerator"> </p>


[RandomProfile](https://pypi.org/project/random-profile/) is a powerful and simple tool to generate fake data. You can use it to mock classes, populate databases and much more. You can check the full documentation here. Check on [Pypi](https://pypi.org/project/random-profile/)


## Documentation

Documentation is available at [ReadTheDocs](https://randomprofilegenerator.readthedocs.io/en/latest/)

## Upcoming Features

- Support for more languages

## Changelog

Check the [Changelog](/CHANGELOG.md) for the latest changes.

## Contributing

Check the [Contributing](/CONTRIBUTING.md) for the contribution guidelines.

## License

The project is licensed under the <a href="/LICENSE">MIT</a> license. 

## Contributors

<a href="https://github.com/codePerfectPlus/awesomeScripts/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=codePerfectPlus/randomprofilegenerator" />
</a>

==> random_profile-1.0.1.tar.gz: random_profile-1.0.1/README.md <==

<h1 align="center">
  <a href="https://pypi.org/project/random-profile/">
  Random Profile Generator
  </a>
  V1.0.1
</h1>

<h4 align="center">Python Module To Generate Random Profile Data</h4>

<p align="center">
<img src="https://img.shields.io/pypi/v/random-profile.svg">
<img src="https://img.shields.io/pypi/pyversions/random-profile.svg">
<img src="https://img.shields.io/pypi/l/random-profile.svg">

</p>
<p align="center">
<img src="https://img.shields.io/pypi/dd/random-profile.svg">
<img src="https://img.shields.io/pypi/dw/random-profile.svg">
<img src="https://img.shields.io/pypi/dm/random-profile.svg">
</p>
<p align="center">

<img alt="GitHub pull-requests" src="https://img.shields.io/github/issues-pr/Py-Contributors/RandomProfileGenerator">

<img alt="GitHub forks" src="https://img.shields.io/github/forks/Py-Contributors/RandomProfileGenerator">

<img alt="contributors" src="https://img.shields.io/github/contributors/Py-Contributors/RandomProfileGenerator">

<img alt="GitHub stars" src="https://img.shields.io/github/stars/Py-Contributors/RandomProfileGenerator"> </p>


[RandomProfile](https://pypi.org/project/random-profile/) is a powerful and simple tool to generate fake data. You can use it to mock classes, populate databases and much more. You can check the full documentation here. Check on [Pypi](https://pypi.org/project/random-profile/)

```sh
pip install random-profile
```

## Documentation

Full Documentation is available at [ReadTheDocs](https://randomprofilegenerator.readthedocs.io/en/latest/)

## Upcoming Features

- More Data Fields
- More Data Types
- Make it more user friendly and easy to use
- Make it more efficient and faster
- Cython Support

## Changelog

Check the [Changelog](/CHANGELOG.md) for the latest changes.

## Contributing

Check the [Contributing](/CONTRIBUTING.md) for the contribution guidelines.

## License

The project is licensed under the <a href="/LICENSE">MIT</a> license.

## Contributors

<a href="https://github.com/codePerfectPlus/awesomeScripts/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=codePerfectPlus/randomprofilegenerator" />
</a>

## Sponsor 

Email: [Pycontributors](mailto:deepak008@live.com) for sponsorship details.
